@@ -77,7 +77,7 @@ function visualiserApp(luigi) {
             taskParams: taskParams,
             displayName: task.display_name,
             priority: task.priority,
-            resources: JSON.stringify(task.resources),
+            resources: JSON.stringify(task.resources).replace(/,"/g, ', "'),
             displayTime: displayTime,
             displayTimestamp: task.last_updated,
             timeRunning: time_running,
@@ -240,6 +240,7 @@ function visualiserApp(luigi) {
         worker.tasks.sort(function(task1, task2) { return task1.timeRunning - task2.timeRunning; });
         worker.start_time = new Date(worker.started * 1000).toLocaleString();
         worker.active = new Date(worker.last_active * 1000).toLocaleString();
+        worker.is_disabled = worker.state === 'disabled';
         return worker;
     }
 
@@ -911,26 +912,9 @@ function visualiserApp(luigi) {
             var tr = $(this).closest('tr');
             var row = dt.row( tr );
             var data = row.data();
-
-            if ( row.child.isShown() ) {
-                // This row is already open - close it
-                row.child.hide();
-            }
-            else {
-                // Open this row
-                row.child(Mustache.render(templates['rowDetailsTemplate'], data)).show();
-
-                // If error state is present retrieve the error
-                if (data.error) {
-                    errorTrace = row.child().find('.error-trace');
-                    luigi.getErrorTrace(data.taskId, function(error) {
-                        errorTrace.html('<pre class="pre-scrollable">'+decodeError(error.error)+'</pre>');
-                    });
-                }
-
-
-            }
-
+            luigi.getErrorTrace(data.taskId, function(error) {
+                showErrorTrace(error);
+            });
         } );
 
         $('#taskTable tbody').on('click', 'td.details-control .re-enable-button', function () {
